pecos.decoders.dummy\_decoder
=============================

.. automodule:: pecos.decoders.dummy_decoder



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.decoders.dummy_decoder.dummy_decoder
